@@ -1,10 +1,12 @@
-from TDhelper.document.excel.meta.modelMeta import modelMeta
+from meta.modelMeta import modelMeta
 class model(metaclass=modelMeta):
     __excelHandle__= None
     __sheetHandle__= None
-    def __init__(self,filePath=''):
-        self.Meta.file= filePath
-        self.__initExcelHandle__()
+    def __init__(self, excelPath= None):
+        if excelPath:
+            self.Meta.file= excelPath
+        if self.Meta.file:
+            self.__initExcelHandle__()
 
     def __initExcelHandle__(self):
         return None
@@ -20,4 +22,5 @@ class model(metaclass=modelMeta):
     
     class Meta:
         file= ''
-        sheet= 'sheet1'
\ No newline at end of file
+        sheet= 'sheet1'
+        extension= 'xlsx'
\ No newline at end of file
