@@ -1,5 +1,5 @@
-from TDhelper.document.excel.model import model 
-from TDhelper.document.excel.FieldType import *
+from model import model 
+from FieldType import *
 import datetime
 
 class stock(model):
@@ -18,20 +18,20 @@ class stock(model):
     stock_volumes_amount = FieldType(float, 13)
     stock_all_market_cap = FieldType(float, 14)
     stock_circulate_market_cap = FieldType(float, 15)
+    def __init__(self, excelPath=None):
+        super(stock,self).__init__(excelPath)
 
-    class Meta:
-        file = 'E:\\1.xlsx'
 
 if __name__ == "__main__":
-    m_obj = stock()
-    m_obj.Meta.file= ''
+    m_obj = stock('E:\\1.csv')
     rowOffset = 2
     while True:
         ret = m_obj.readLine(rowOffset)
+        rowOffset = 1
         if not ret:
             break
         for (k,v) in ret.__dict__.items():
             if k.startswith('stock_'):
                 print(v)
         print('-----------------------\r')
-        rowOffset += 1
+        #rowOffset += 1
\ No newline at end of file
